# -*- coding: utf-8 -*-

from __future__ import absolute_import, print_function, unicode_literals

def main():
    from rpy.cli.dispatch import execute_from_command_line
    execute_from_command_line()    

if __name__ == '__main__':
    main()

